##########################################################################
# Functions exporta and exportp are used to append/prepend correspondingly 
# one directory or a set of directories separated by semicolon symbol (':')
# to the environment variables like PATH, LD_LIBRARY_PATH, PYTHONPATH,
# LD_RUN_PATH etc. 
# The main purpose is to replace default setenv command behavior:
# exporta, exportp also remove duplicated entries, shortening in that way
# the environment variables.
# If some directory being added is already included into the variable
# nothing is done for it.
# Note, that these functions work some slower that setenv command itself.
#
#### cleandup ###
# appends/prepends set of directories (second parameter) 
# to the another set of directories (first parameter) and
# removes duplicated entries;
# the third parameter defines the mode: 0 - append, 1 - prepend
cleandup() {
out_var=`echo $1 $2 | awk -v dir=$3 '{                   \
     na = split($2,a,":");                               \
     k1=0;                                               \
     bbb[k1++]="";                                       \
     ccc[""];                                            \
     if($1 != "<empty>") {                               \
       nb = split($1,b,":");                             \
       for(i=1;i<=nb;i++) {                              \
         if(!(b[i] in ccc) ) {                           \
	   ccc[b[i]];                                    \
           bbb[k1++]=b[i];                               \
	 };                                              \
       };                                                \
     };                                                  \
     k2=0;                                               \
     aaa[k2++]="";                                       \
     for(i=1;i<=na;i++) {                                \
       if(!(a[i] in ccc)) {                              \
         ccc[a[i]];                                      \
         aaa[k2++]=a[i];                                 \
       };                                                \
     };                                                  \
     ORS=":";                                            \
     if(dir) {                                           \
       for(i=1;i<k2;i++) {                               \
         print aaa[i];                                   \
       }                                                 \
       for(i=1;i<k1;i++) {                               \
         print bbb[i];                                   \
       }                                                 \
     }                                                   \
     else {                                              \
       for(i=1;i<k1;i++) {                               \
         print bbb[i];                                   \
       }                                                 \
       for(i=1;i<k2;i++) {                               \
         print aaa[i];                                   \
       }                                                 \
     }                                                   \
   }' | sed -e 's/\(.*\):/\1/g'`
echo $out_var
}
### exporta ###
# appends directory or set of directories, separated by ':' (second parameter)
# to the variable (first parameter)
exporta () { 
xenv=`printenv $1`
if [ -z "$xenv" ]; then xenv="<empty>"; fi
out_var=`cleandup $xenv $2 0`
export $1=$out_var
}
### exportp ###
# prepends directory or set of directories, separated by ':' (second parameter)
# to the variable (first parameter)
exportp () { 
xenv=`printenv $1`
if [ -z "$xenv" ]; then xenv="<empty>"; fi
out_var=`cleandup $xenv $2 1`
export $1=$out_var
}
###########################################################################

#------ Setting products installation directory ------
export INST_ROOT=/home/andrico/salome_5.1.5

#------ Environment switch: 0 for SALOME building, 1 for SALOME launching ------
export ENV_FOR_LAUNCH=1

#------ License activation ------
export LICENSE_FILE=/product/distene/dlim8.var.sh

if [ -e "${LICENSE_FILE}" ] ; then
export SIMULOGD_LICENSE_FILE=29029@soleil
source ${LICENSE_FILE}
fi

#------ tcltk ------
export TCLHOME=${INST_ROOT}/tcltk-8.4.14
exportp PATH ${TCLHOME}/bin
exportp LD_LIBRARY_PATH ${TCLHOME}/lib
export TCLLIBPATH="${TCLHOME}/lib ${TCLHOME}/lib/tcl8.4 ${TCLHOME}/lib/tk8.4"
##
## #------ tcltk_src ------
## # nothing to do
## ##
#------ Python ------
export PYTHONROOT=${INST_ROOT}/Python-2.4.4
export PYTHONHOME=$PYTHONROOT
exportp PATH ${PYTHONROOT}/bin
exportp LD_LIBRARY_PATH ${PYTHONROOT}/lib
export PYTHON_VERSION=`python -c "import sys; print sys.version[:3]"`
export PYTHON_INCLUDE=${PYTHONROOT}/include/python${PYTHON_VERSION}
export PYTHONPATH=${PYTHONROOT}/lib/python${PYTHON_VERSION}
##
## #------ Python_src ------
## # nothing to do
## ##
#------ Qt ------
export QTDIR=${INST_ROOT}/qt-4.5.2
exportp PATH ${QTDIR}/bin 
exportp LD_LIBRARY_PATH ${QTDIR}/lib
export QT_PLUGIN_PATH=${QTDIR}/plugins
##
## #------ Qt_src ------
## # nothing to do
## ##
#------ QScintilla ------
export QSCINTILLA_DIR=${INST_ROOT}/QScintilla-2.4
exportp LD_LIBRARY_PATH ${QSCINTILLA_DIR}/lib
##
## #------ QScintilla_src ------
## # nothing to do
## ##
#------ Sip ------
export SIPDIR=${INST_ROOT}/sip-4.8.2
exportp PATH ${SIPDIR}/bin
exportp PYTHONPATH ${SIPDIR}/lib/python${PYTHON_VERSION}/site-packages
exportp LD_LIBRARY_PATH ${SIPDIR}/lib/python${PYTHON_VERSION}/site-packages
##
## #------ Sip_src ------
## # nothing to do
## ##
#------ PyQt ------
export PYQTDIR=${INST_ROOT}/PyQt-4.5.4
export PYQT_SIPS=${PYQTDIR}/sip
exportp PATH ${PYQTDIR}/bin
exportp PYTHONPATH ${PYQTDIR}:${PYQTDIR}/PyQt4
exportp LD_LIBRARY_PATH ${PYQTDIR}/PyQt4
##
## #------ PyQt_src ------
## # nothing to do
## ##
#------ boost ------ 
export BOOSTDIR=${INST_ROOT}/boost-1.40.0
exportp LD_LIBRARY_PATH ${BOOSTDIR}/lib
exportp PATH ${BOOSTDIR}/include
##
## #------ boost_src ------
## # nothing to do
## ##
#------ Swig ------ 
export SWIG_ROOT=${INST_ROOT}/SWIG-1.3.40
exportp PATH ${SWIG_ROOT}/bin
export SWIG_LIB=${SWIG_ROOT}/share/swig/1.3.40
##
## #------ Swig_src ------
## # nothing to do
## ##
#------ OpenCascade ------
export CASROOT=${INST_ROOT}/CAS-6.3sp10
exportp PATH ${CASROOT}/bin
exportp LD_LIBRARY_PATH ${CASROOT}/lib:${CASROOT}/lin/lib
# Variable for Foundation Classes : 
export CSF_UnitsLexicon=${CASROOT}/src/UnitsAPI/Lexi_Expr.dat 
export CSF_UnitsDefinition=${CASROOT}/src/UnitsAPI/Units.dat 
# Variable for DataExchange : 
export CSF_SHMessage=${CASROOT}/src/SHMessage
export CSF_XSMessage=${CASROOT}/src/XSMessage 
# Variable for Font : 
export CSF_MDTVFontDirectory=${CASROOT}/src/FontMFT 
export CSF_MDTVTexturesDirectory=${CASROOT}/src/Textures 
# Activation of OCCT Kernel multithreading :
export MMGT_REENTRANT=1
##
## #------ OpenCascade_src ------
## # nothing to do
## ##
#------ Qwt ------
export QWTHOME=${INST_ROOT}/qwt-5.2.0
exportp LD_LIBRARY_PATH ${QWTHOME}/lib 
##
## #------ Qwt_src ------
## # nothing to do
## ##
#------ OmniORB ------
export OMNIORBDIR=${INST_ROOT}/omniORB-4.1.4
export OMNIORB_CONFIG=${OMNIORBDIR}/.omniORB.cfg
exportp PYTHONPATH ${OMNIORBDIR}/lib:${OMNIORBDIR}/lib/python${PYTHON_VERSION}/site-packages
exportp PATH $OMNIORBDIR/bin
exportp LD_LIBRARY_PATH $OMNIORBDIR/lib 
##
## #------ OmniORB_src ------
## # nothing to do
## ##
#------ Hdf ------
export HDF5HOME=${INST_ROOT}/hdf5-1.6.9
exportp PATH ${HDF5HOME}/bin
exportp LD_LIBRARY_PATH ${HDF5HOME}/lib
##
## #------ Hdf_src ------
## # nothing to do
## ##
#------ Med ------
export MED2HOME=${INST_ROOT}/med-2.3.6
exportp PATH ${MED2HOME}/bin
exportp LD_LIBRARY_PATH ${MED2HOME}/lib
##
## #------ Med_src ------
## # nothing to do
## ##
#------ Metis ------ 
export METISDIR=${INST_ROOT}/metis-4.0
##
## #------ Metis_src ------
## # nothing to do
## ##
#------ Scotch ------ 
export SCOTCHDIR=${INST_ROOT}/scotch-4.0
##
## #------ Scotch_src ------
## # nothing to do
## ##
#------ cmake ------
export CMAKEHOME=${INST_ROOT}/cmake-2.6.4
exportp PATH ${CMAKEHOME}/bin
##
## #------ cmake_src ------
## # nothing to do
## ##
#------ Vtk ------
export VTKHOME=${INST_ROOT}/VTK-5.0.4
exportp PATH ${VTKHOME}/bin
exportp LD_LIBRARY_PATH ${VTKHOME}/lib
exportp PYTHONPATH ${VTKHOME}/lib/python${PYTHON_VERSION}/site-packages
export TCLLIBPATH="${VTKHOME}/lib/vtk-5.0/tcl ${TCLLIBPATH}"
##
## #------ Vtk_src ------
## # nothing to do
## ##
#------ numpy ------
exportp PYTHONPATH ${INST_ROOT}/numpy-1.3.0/lib/python${PYTHON_VERSION}/site-packages
exportp PATH ${INST_ROOT}/numpy-1.3.0/bin
exportp LD_LIBRARY_PATH ${INST_ROOT}/numpy-1.3.0/lib
##
## #------ numpy_src ------
## # nothing to do
## ##
#------ libBatch ------ 
export LIBBATCH_ROOT_DIR=${INST_ROOT}/libBatch-1.2.0
export PYTHON_VERSION=`python -c "import sys; print sys.version[:3]"`
exportp LD_LIBRARY_PATH ${LIBBATCH_ROOT_DIR}/lib
exportp PYTHONPATH ${LIBBATCH_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages
##
## #------ libBatch_src ------
## # nothing to do
## ##
#------ expat ------
export EXPAT_ROOT=${INST_ROOT}/expat-2.0.1
exportp PATH ${EXPAT_ROOT}/bin
exportp LD_LIBRARY_PATH ${EXPAT_ROOT}/lib
##
## #------ expat_src ------
## # nothing to do
## ##
#------ Graphviz ------
export GRAPHVIZHOME=${INST_ROOT}/graphviz-2.24.0
exportp PATH ${GRAPHVIZHOME}/bin
exportp LD_LIBRARY_PATH ${GRAPHVIZHOME}/lib:${GRAPHVIZHOME}/lib/graphviz
##
## #------ Graphviz_src ------
## # nothing to do
## ##
#------ Doxygen ------
exportp PATH ${INST_ROOT}/doxygen-1.6.1/bin
##
## #------ Doxygen_src ------
## # nothing to do
## ##
#------ docutils ------
exportp PYTHONPATH ${INST_ROOT}/docutils-0.6.0/lib/python${PYTHON_VERSION}/site-packages
exportp PATH ${INST_ROOT}/docutils-0.6.0/bin
##
## #------ docutils_src ------
## # nothing to do
## ##
#------ Sphinx ------
exportp PYTHONPATH ${INST_ROOT}/sphinx-0.6.3/lib/python${PYTHON_VERSION}/site-packages
exportp PATH ${INST_ROOT}/sphinx-0.6.3/bin
##
## #------ Sphinx_src ------
## # nothing to do
## ##
#------ netgen ------
export NETGENHOME=${INST_ROOT}/netgen-4.5
##
## #------ netgen_src ------
## # nothing to do
## ##
#------ libxml2 ------ 
export LIBXML_DIR=${INST_ROOT}/libxml2-2.6.27
exportp PATH ${LIBXML_DIR}/bin
exportp LD_LIBRARY_PATH ${LIBXML_DIR}/lib
##
## #------ libxml2_src ------
## # nothing to do
## ##
#------ KERNEL ------
export KERNEL_ROOT_DIR=${INST_ROOT}/KERNEL_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${KERNEL_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${KERNEL_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${KERNEL_ROOT_DIR}/bin/salome:${KERNEL_ROOT_DIR}/lib/salome:${KERNEL_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ KERNEL_src ------
export KERNEL_SRC_DIR=${INST_ROOT}/KERNEL_SRC_5.1.5
##
#------ GUI ------
export GUI_ROOT_DIR=${INST_ROOT}/GUI_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${GUI_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${GUI_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${GUI_ROOT_DIR}/bin/salome:${GUI_ROOT_DIR}/lib/salome:${GUI_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ GUI_src ------
export GUI_SRC_DIR=${INST_ROOT}/GUI_SRC_5.1.5
##
#------ GEOM ------
export GEOM_ROOT_DIR=${INST_ROOT}/GEOM_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${GEOM_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${GEOM_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${GEOM_ROOT_DIR}/bin/salome:${GEOM_ROOT_DIR}/lib/salome:${GEOM_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ GEOM_src ------
export GEOM_SRC_DIR=${INST_ROOT}/GEOM_SRC_5.1.5
##
#------ MED ------
export MED_ROOT_DIR=${INST_ROOT}/MED_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${MED_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${MED_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${MED_ROOT_DIR}/bin/salome:${MED_ROOT_DIR}/lib/salome:${MED_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ MED_src ------
export MED_SRC_DIR=${INST_ROOT}/MED_SRC_5.1.5
##
#------ SMESH ------
export SMESH_ROOT_DIR=${INST_ROOT}/SMESH_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${SMESH_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${SMESH_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${SMESH_ROOT_DIR}/bin/salome:${SMESH_ROOT_DIR}/lib/salome:${SMESH_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ SMESH_src ------
export SMESH_SRC_DIR=${INST_ROOT}/SMESH_SRC_5.1.5
##
#------ VISU ------
export VISU_ROOT_DIR=${INST_ROOT}/VISU_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${VISU_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${VISU_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${VISU_ROOT_DIR}/bin/salome:${VISU_ROOT_DIR}/lib/salome:${VISU_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ VISU_src ------
export VISU_SRC_DIR=${INST_ROOT}/VISU_SRC_5.1.5
##
#------ NETGENPLUGIN ------
export NETGENPLUGIN_ROOT_DIR=${INST_ROOT}/NETGENPLUGIN_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp LD_LIBRARY_PATH ${NETGENPLUGIN_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${NETGENPLUGIN_ROOT_DIR}/lib/salome:${NETGENPLUGIN_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ NETGENPLUGIN_src ------
export NETGENPLUGIN_SRC_DIR=${INST_ROOT}/NETGENPLUGIN_SRC_5.1.5
##
#------ GHS3DPLUGIN ------
export GHS3DPLUGIN_ROOT_DIR=${INST_ROOT}/GHS3DPLUGIN_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp LD_LIBRARY_PATH ${GHS3DPLUGIN_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${GHS3DPLUGIN_ROOT_DIR}/lib/salome:${GHS3DPLUGIN_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ GHS3DPLUGIN_src ------
export GHS3DPLUGIN_SRC_DIR=${INST_ROOT}/GHS3DPLUGIN_SRC_5.1.5
##
#------ GHS3DPRLPLUGIN ------
export GHS3DPRLPLUGIN_ROOT_DIR=${INST_ROOT}/GHS3DPRLPLUGIN_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${GHS3DPRLPLUGIN_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${GHS3DPRLPLUGIN_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${GHS3DPRLPLUGIN_ROOT_DIR}/bin/salome:${GHS3DPRLPLUGIN_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ GHS3DPRLPLUGIN_src ------
export GHS3DPRLPLUGIN_SRC_DIR=${INST_ROOT}/GHS3DPRLPLUGIN_SRC_5.1.5
##
#------ HexoticPLUGIN ------
export HexoticPLUGIN_ROOT_DIR=${INST_ROOT}/HexoticPLUGIN_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${HexoticPLUGIN_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${HexoticPLUGIN_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${HexoticPLUGIN_ROOT_DIR}/bin/salome:${HexoticPLUGIN_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ HexoticPLUGIN_src ------
export HexoticPLUGIN_SRC_DIR=${INST_ROOT}/HexoticPLUGIN_SRC_5.1.5
##
#------ BLSURFPLUGIN ------
export BLSURFPLUGIN_ROOT_DIR=${INST_ROOT}/BLSURFPLUGIN_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${BLSURFPLUGIN_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${BLSURFPLUGIN_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${BLSURFPLUGIN_ROOT_DIR}/bin/salome:${BLSURFPLUGIN_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ BLSURFPLUGIN_src ------
export BLSURFPLUGIN_SRC_DIR=${INST_ROOT}/BLSURFPLUGIN_SRC_5.1.5
##
#------ COMPONENT ------
export COMPONENT_ROOT_DIR=${INST_ROOT}/COMPONENT_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${COMPONENT_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${COMPONENT_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${COMPONENT_ROOT_DIR}/bin/salome:${COMPONENT_ROOT_DIR}/lib/salome:${COMPONENT_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ COMPONENT_src ------
export COMPONENT_SRC_DIR=${INST_ROOT}/COMPONENT_SRC_5.1.5
##
#------ PYCALCULATOR ------
export PYCALCULATOR_ROOT_DIR=${INST_ROOT}/PYCALCULATOR_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${PYCALCULATOR_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${PYCALCULATOR_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${PYCALCULATOR_ROOT_DIR}/bin/salome:${PYCALCULATOR_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ PYCALCULATOR_src ------
export PYCALCULATOR_SRC_DIR=${INST_ROOT}/PYCALCULATOR_SRC_5.1.5
##
#------ CALCULATOR ------
export CALCULATOR_ROOT_DIR=${INST_ROOT}/CALCULATOR_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${CALCULATOR_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${CALCULATOR_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${CALCULATOR_ROOT_DIR}/bin/salome:${CALCULATOR_ROOT_DIR}/lib/salome:${CALCULATOR_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ CALCULATOR_src ------
export CALCULATOR_SRC_DIR=${INST_ROOT}/CALCULATOR_SRC_5.1.5
##
#------ HELLO ------
export HELLO_ROOT_DIR=${INST_ROOT}/HELLO_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${HELLO_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${HELLO_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${HELLO_ROOT_DIR}/bin/salome:${HELLO_ROOT_DIR}/lib/salome:${HELLO_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ HELLO_src ------
export HELLO_SRC_DIR=${INST_ROOT}/HELLO_SRC_5.1.5
##
#------ PYHELLO ------
export PYHELLO_ROOT_DIR=${INST_ROOT}/PYHELLO_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${PYHELLO_ROOT_DIR}/bin/salome
    exportp PYTHONPATH ${PYHELLO_ROOT_DIR}/bin/salome:${PYHELLO_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ PYHELLO_src ------
export PYHELLO_SRC_DIR=${INST_ROOT}/PYHELLO_SRC_5.1.5
##
#------ LIGHT ------
export LIGHT_ROOT_DIR=${INST_ROOT}/LIGHT_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp LD_LIBRARY_PATH ${LIGHT_ROOT_DIR}/lib/salome
  fi
fi
##
#------ LIGHT_src ------
export LIGHT_SRC_DIR=${INST_ROOT}/LIGHT_SRC_5.1.5
##
#------ PYLIGHT ------
export PYLIGHT_ROOT_DIR=${INST_ROOT}/PYLIGHT_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${PYLIGHT_ROOT_DIR}/bin/salome
    exportp PYTHONPATH ${PYLIGHT_ROOT_DIR}/bin/salome
  fi
fi
##
#------ PYLIGHT_src ------
export PYLIGHT_SRC_DIR=${INST_ROOT}/PYLIGHT_SRC_5.1.5
##
#------ RANDOMIZER ------
export RANDOMIZER_ROOT_DIR=${INST_ROOT}/RANDOMIZER_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${RANDOMIZER_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${RANDOMIZER_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${RANDOMIZER_ROOT_DIR}/bin/salome:${RANDOMIZER_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ RANDOMIZER_src ------
export RANDOMIZER_SRC_DIR=${INST_ROOT}/RANDOMIZER_SRC_5.1.5
##
#------ SIERPINSKY ------
export SIERPINSKY_ROOT_DIR=${INST_ROOT}/SIERPINSKY_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${SIERPINSKY_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${SIERPINSKY_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${SIERPINSKY_ROOT_DIR}/bin/salome:${SIERPINSKY_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ SIERPINSKY_src ------
export SIERPINSKY_SRC_DIR=${INST_ROOT}/SIERPINSKY_SRC_5.1.5
##
#------ MULTIPR ------
export MULTIPR_ROOT_DIR=${INST_ROOT}/MULTIPR_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${MULTIPR_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${MULTIPR_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${MULTIPR_ROOT_DIR}/bin/salome:${MULTIPR_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ MULTIPR_src ------
export MULTIPR_SRC_DIR=${INST_ROOT}/MULTIPR_SRC_5.1.5
##
#------ YACS ------
export YACS_ROOT_DIR=${INST_ROOT}/YACS_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${YACS_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${YACS_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${YACS_ROOT_DIR}/bin/salome:${YACS_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ YACS_src ------
export YACS_SRC_DIR=${INST_ROOT}/YACS_SRC_5.1.5
##
#------ YACSGEN ------
export YACSGEN_ROOT_DIR=${INST_ROOT}/YACSGEN_5.1.5
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PYTHONPATH ${YACSGEN_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/module_generator
  fi
fi
##
#------ YACSGEN_src ------
export YACSGEN_SRC_DIR=${INST_ROOT}/YACSGEN_SRC_5.1.5
##
#------ JOBMANAGER ------
export JOBMANAGER_ROOT_DIR=${INST_ROOT}/JOBMANAGER_0.1
if [ -n "${ENV_FOR_LAUNCH}" ] ; then
  if [ "${ENV_FOR_LAUNCH}" == "1" ] ; then
    exportp PATH ${JOBMANAGER_ROOT_DIR}/bin/salome
    exportp LD_LIBRARY_PATH ${JOBMANAGER_ROOT_DIR}/lib/salome
    exportp PYTHONPATH ${JOBMANAGER_ROOT_DIR}/bin/salome:${JOBMANAGER_ROOT_DIR}/lib/salome:${JOBMANAGER_ROOT_DIR}/lib/python${PYTHON_VERSION}/site-packages/salome
  fi
fi
##
#------ JOBMANAGER_src ------
export JOBMANAGER_SRC_DIR=${INST_ROOT}/JOBMANAGER_SRC_0.1
##
#------ SAMPLES_src ------
export DATA_DIR=${INST_ROOT}/SAMPLES_SRC_5.1.5
##
#------ xdata ------ 
export XDATAROOT=${INST_ROOT}/xdata-0.7.3
exportp PATH ${XDATAROOT}/bin
export PYTHON_VERSION=`python -c "import sys; print sys.version[:3]"`
exportp PYTHONPATH ${XDATAROOT}/lib/python${PYTHON_VERSION}/site-packages/xdata
##
#------ xdata_src ------
# nothing to do
##
#------ HXX2SALOME ------
export HXX2SALOME_ROOT_DIR=${INST_ROOT}/HXX2SALOME_5.1.5/bin
exportp PATH ${HXX2SALOME_ROOT_DIR}
##
#------ HXX2SALOME_src ------
# nothing to do
##
#------ HXX2SALOMEDOC ------
#nothing to do
##
#------ HXX2SALOMEDOC_src ------
# nothing to do
##
#------ DOCUMENTATION_src ------
#nothing to do
##
